Job

Struct Job 

pub struct Job {
Show 15 fields pub command: Option<String>, pub created_at: DateTime<Utc>, pub depends_on: Vec<Uuid>, pub error_code: Option<String>, pub error_message: Option<String>, pub exit_code: Option<i64>, pub finished_at: Option<DateTime<Utc>>, pub id: Uuid, pub name: Option<String>, pub retry_policy: Option<Map<String, Value>>, pub soft_fail_policy: Option<Map<String, Value>>, pub soft_failed: bool, pub started_at: Option<DateTime<Utc>>, pub state: JobState, pub step_key: Option<String>,
}
One job (DAG node) of a build.

JSON schema
{
 "title": "Job",
 "description": "One job (DAG node) of a build.",
 "type": "object",
 "required": [
   "created_at",
   "depends_on",
   "id",
   "soft_failed",
   "state"
 ],
 "properties": {
   "command": {
     "description": "The shell command the job runs.",
     "type": [
       "string",
       "null"
     ]
   },
   "created_at": {
     "description": "When the job row was created.",
     "type": "string",
     "format": "date-time"
   },
   "depends_on": {
     "description": "Ids of this job's prerequisite jobs (its DAG
in-edges), spanning both `depends_on` and `builds_in` dependency kinds.
Empty when the job has no prerequisites.",
     "type": "array",
     "items": {
       "type": "string",
       "format": "uuid"
     }
   },
   "error_code": {
     "description": "Stable job-level error code, if the job failed.",
     "type": [
       "string",
       "null"
     ]
   },
   "error_message": {
     "description": "Human-readable job-level error message, if any.",
     "type": [
       "string",
       "null"
     ]
   },
   "exit_code": {
     "description": "The command's exit status, once finished.",
     "type": [
       "integer",
       "null"
     ]
   },
   "finished_at": {
     "description": "When the job reached a terminal state.",
     "type": [
       "string",
       "null"
     ],
     "format": "date-time"
   },
   "id": {
     "description": "The job's id.",
     "type": "string",
     "format": "uuid"
   },
   "name": {
     "description": "Human-readable job name.",
     "type": [
       "string",
       "null"
     ]
   },
   "retry_policy": {
     "description": "The job's retry policy, if any.",
     "type": [
       "object",
       "null"
     ],
     "additionalProperties": true
   },
   "soft_fail_policy": {
     "description": "The job's soft-fail policy, if any.",
     "type": [
       "object",
       "null"
     ],
     "additionalProperties": true
   },
   "soft_failed": {
     "description": "Whether the job failed but the build was allowed to
continue.",
     "type": "boolean"
   },
   "started_at": {
     "description": "When the job started running.",
     "type": [
       "string",
       "null"
     ],
     "format": "date-time"
   },
   "state": {
     "description": "The job's FSM state.",
     "type": "string",
     "enum": [
       "pending",
       "scheduled",
       "assigned",
       "running",
       "passed",
       "failed",
       "skipped",
       "canceling",
       "canceled",
       "timing_out",
       "timed_out"
     ]
   },
   "step_key": {
     "description": "The job's stable key within the build's DAG.",
     "type": [
       "string",
       "null"
     ]
   }
 }
}

Fields

command: Option<String>

The shell command the job runs.

created_at: DateTime<Utc>

When the job row was created.

depends_on: Vec<Uuid>

Ids of this job’s prerequisite jobs (its DAG in-edges), spanning both depends_on and builds_in dependency kinds. Empty when the job has no prerequisites.

error_code: Option<String>

Stable job-level error code, if the job failed.

error_message: Option<String>

Human-readable job-level error message, if any.

exit_code: Option<i64>

The command’s exit status, once finished.

finished_at: Option<DateTime<Utc>>

When the job reached a terminal state.

id: Uuid

The job’s id.

name: Option<String>

Human-readable job name.

retry_policy: Option<Map<String, Value>>

The job’s retry policy, if any.

soft_fail_policy: Option<Map<String, Value>>

The job’s soft-fail policy, if any.

soft_failed: bool

Whether the job failed but the build was allowed to continue.

started_at: Option<DateTime<Utc>>

When the job started running.

state: JobState

The job’s FSM state.

step_key: Option<String>

The job’s stable key within the build’s DAG.