pub struct CheckoutRequest {
pub amount_cents: i64,
}Expand description
Starts a Stripe Checkout Session crediting the organization identified
by the path (:org). The body carries only the top-up amount in cents.
JSON schema
{
"title": "CheckoutRequest",
"description": "Starts a Stripe Checkout Session crediting the
organization identified by the path (`:org`). The body carries only the
top-up amount in cents.",
"type": "object",
"required": [
"amount_cents"
],
"properties": {
"amount_cents": {
"description": "The credit top-up amount in cents. Must be a
positive integer within the supported bounds (100–1,000,000).",
"type": "integer",
"maximum": 1000000.0,
"minimum": 100.0
}
}
}Fields
amount_cents: i64The credit top-up amount in cents. Must be a positive integer within the supported bounds (100–1,000,000).