pub struct RedeemCouponResponse {
pub balance_cents: i64,
pub credit_cents: i64,
}Expand description
The credit granted by the coupon and the organization’s resulting balance, both in cents.
JSON schema
{
"title": "RedeemCouponResponse",
"description": "The credit granted by the coupon and the organization's
resulting balance, both in cents.",
"type": "object",
"required": [
"balance_cents",
"credit_cents"
],
"properties": {
"balance_cents": {
"description": "The organization's balance after the credit, in
cents.",
"type": "integer"
},
"credit_cents": {
"description": "The credit granted by the coupon, in cents.",
"type": "integer"
}
}
}Fields
balance_cents: i64The organization’s balance after the credit, in cents.
credit_cents: i64The credit granted by the coupon, in cents.